Welcome to pcuf's documentation!
======================================
.. include:: ./readme.rst


.. toctree::
   :hidden:
   :glob:

   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
